==> jei-1.20.1-fabric-15.20.0.110-sources.jar: mezz/jei/fabric/platform/RecipeHelper.java <==
package mezz.jei.fabric.platform;

import mezz.jei.api.recipe.vanilla.IJeiBrewingRecipe;
import mezz.jei.api.recipe.vanilla.IVanillaRecipeFactory;
import mezz.jei.api.runtime.IIngredientManager;
import mezz.jei.common.platform.IPlatformRecipeHelper;
import net.minecraft.class_1856;
import net.minecraft.class_1860;
import net.minecraft.class_1869;
import net.minecraft.class_2960;
import net.minecraft.class_3955;
import net.minecraft.class_8059;
import net.minecraft.class_8060;
import net.minecraft.class_8062;
import java.util.List;
import java.util.Optional;

public class RecipeHelper implements IPlatformRecipeHelper {
	@Override
	public <T extends class_3955> int getWidth(T recipe) {
		if (recipe instanceof class_1869 shapedRecipe) {
			return shapedRecipe.method_8150();
		}
		return 0;
	}

	@Override
	public <T extends class_3955> int getHeight(T recipe) {
		if (recipe instanceof class_1869 shapedRecipe) {
			return shapedRecipe.method_8158();
		}
		return 0;
	}

	@Override
	public class_1856 getBase(class_8059 recipe) {
		if (recipe instanceof class_8060 transformRecipe) {
			return transformRecipe.field_42031;
		}
		if (recipe instanceof class_8062 trimRecipe) {
			return trimRecipe.field_42036;
		}
		return class_1856.field_9017;
	}

	@Override
	public class_1856 getAddition(class_8059 recipe) {
		if (recipe instanceof class_8060 transformRecipe) {
			return transformRecipe.field_42032;
		}
		if (recipe instanceof class_8062 trimRecipe) {
			return trimRecipe.field_42037;
		}
		return class_1856.field_9017;
	}

	@Override
	public class_1856 getTemplate(class_8059 recipe) {
		if (recipe instanceof class_8060 transformRecipe) {
			return transformRecipe.field_42030;
		}
		if (recipe instanceof class_8062 trimRecipe) {
			return trimRecipe.field_42035;
		}
		return class_1856.field_9017;
	}

	@SuppressWarnings("OptionalOfNullableMisuse")
	@Override
	public Optional<class_2960> getRegistryNameForRecipe(class_1860<?> recipe) {
		class_2960 id = recipe.method_8114();
		return Optional.ofNullable(id);
	}

	@Override
	public List<IJeiBrewingRecipe> getBrewingRecipes(IIngredientManager ingredientManager, IVanillaRecipeFactory vanillaRecipeFactory) {
		return BrewingRecipeMaker.getBrewingRecipes(ingredientManager, vanillaRecipeFactory);
	}
}

==> jei-1.21.1-fabric-19.22.0.315-sources.jar: mezz/jei/fabric/platform/RecipeHelper.java <==
package mezz.jei.fabric.platform;

import mezz.jei.api.recipe.vanilla.IJeiBrewingRecipe;
import mezz.jei.api.recipe.vanilla.IVanillaRecipeFactory;
import mezz.jei.api.runtime.IIngredientManager;
import mezz.jei.common.platform.IPlatformRecipeHelper;
import net.minecraft.class_1845;
import net.minecraft.class_1856;
import net.minecraft.class_8059;
import net.minecraft.class_8060;
import net.minecraft.class_8062;
import java.util.List;

public class RecipeHelper implements IPlatformRecipeHelper {
	@Override
	public class_1856 getBase(class_8059 recipe) {
		if (recipe instanceof class_8060 transformRecipe) {
			return transformRecipe.field_42031;
		}
		if (recipe instanceof class_8062 trimRecipe) {
			return trimRecipe.field_42036;
		}
		return class_1856.field_9017;
	}

	@Override
	public class_1856 getAddition(class_8059 recipe) {
		if (recipe instanceof class_8060 transformRecipe) {
			return transformRecipe.field_42032;
		}
		if (recipe instanceof class_8062 trimRecipe) {
			return trimRecipe.field_42037;
		}
		return class_1856.field_9017;
	}

	@Override
	public class_1856 getTemplate(class_8059 recipe) {
		if (recipe instanceof class_8060 transformRecipe) {
			return transformRecipe.field_42030;
		}
		if (recipe instanceof class_8062 trimRecipe) {
			return trimRecipe.field_42035;
		}
		return class_1856.field_9017;
	}

	@Override
	public List<IJeiBrewingRecipe> getBrewingRecipes(IIngredientManager ingredientManager, IVanillaRecipeFactory vanillaRecipeFactory, class_1845 potionBrewing) {
		return BrewingRecipeMaker.getBrewingRecipes(ingredientManager, vanillaRecipeFactory, potionBrewing);
	}
}
